@@ -20,36 +20,39 @@ Command for scoring MT systems.
 optional arguments:
   -h, --help            Show this help message and exit.
   -s SOURCES, --sources SOURCES
-                        (required unless using -d, type: Path_fr)
-  -t TRANSLATIONS, --translations TRANSLATIONS
-                        (required, type: Path_fr)
+                        (type: Path_fr, default: null)
+  -t TRANSLATIONS [TRANSLATIONS ...], --translations TRANSLATIONS [TRANSLATIONS ...]
+                        (type: Path_fr, default: null)
   -r REFERENCES, --references REFERENCES
-                        (type: Path_fr, default: None)
-  -d SACREBLEU_TESTSET, --sacrebleu_dataset SACREBLEU_TESTSET
-                        (optional, use in place of -s and -r, type: str
-                         format TESTSET:LANGPAIR, e.g., wmt20:en-de)
-  --to_json TO_JSON     (type: Union[bool, str], default: False)
-  --model MODEL         (type: Union[str, Path_fr], default: wmt21-large-estimator)
+                        (type: Path_fr, default: null)
+  -d SACREBLEU_DATASET, --sacrebleu_dataset SACREBLEU_DATASET
+                        (type: str, default: null)
   --batch_size BATCH_SIZE
                         (type: int, default: 8)
   --gpus GPUS           (type: int, default: 1)
+  --quiet               Prints only the final system score. (default: False)
   --accelerator {dp,ddp}
                         Pytorch Lightnining accelerator for multi-GPU. (type: str, default: ddp)
-  --disable_bar         Disables progress bar. (default: True)
   --to_json TO_JSON     Exports results to a json file. (type: Union[bool, str], default: False)
-  --model {emnlp20-comet-rank,wmt20-comet-da,wmt20-comet-qe-da,wmt21-comet-mqm,wmt21-cometinho-da,wmt21-comet-qe-mqm}
-                        COMET model to be used. (type: Union[str, Path_fr], default: wmt20-comet-da)
+  --model MODEL         COMET model to be used. (type: str, default: wmt20-comet-da)
+  --model_storage_path MODEL_STORAGE_PATH
+                        Path to the directory where models will be stored. By default its saved in ~/.cache/torch/unbabel_comet/ (default: null)
   --mc_dropout MC_DROPOUT
-                        Number of inference runs for each sample in MC Dropout. 
-                        (type: Union[bool, int], default: False)
+                        Number of inference runs for each sample in MC Dropout. (type: Union[bool, int], default: False)
   --seed_everything SEED_EVERYTHING
                         Prediction seed. (type: int, default: 12)
+  --num_workers NUM_WORKERS
+                        Number of workers to use when loading data. (type: int, default: 2)
+  --disable_bar         Disables progress bar. (default: False)
+  --disable_cache       Disables sentence embeddings caching. This makes inference slower but saves memory. (default: False)
+  --disable_length_batching
+                        Disables length batching. This makes inference slower. (default: False)
+  --print_cache_info    Print information about COMET cache. (default: False)
 """
 import itertools
 import json
-import multiprocessing
 import os
-from typing import Dict, List, Optional, Union
+from typing import Union
 
 import numpy as np
 import torch
@@ -71,6 +74,9 @@ def score_command() -> None:
     parser.add_argument("-d", "--sacrebleu_dataset", type=str)
     parser.add_argument("--batch_size", type=int, default=8)
     parser.add_argument("--gpus", type=int, default=1)
+    parser.add_argument(
+        "--quiet", action="store_true", help="Prints only the final system score."
+    )
     parser.add_argument(
         "--accelerator",
         type=str,
@@ -115,7 +121,7 @@ def score_command() -> None:
         "--num_workers",
         help="Number of workers to use when loading data.",
         type=int,
-        default=multiprocessing.cpu_count(),
+        default=2,
     )
     parser.add_argument(
         "--disable_bar", action="store_true", help="Disables progress bar."
@@ -183,18 +189,18 @@ def score_command() -> None:
     if not cfg.disable_cache:
         model.set_embedding_cache()
 
-    with open(cfg.sources()) as fp:
+    with open(cfg.sources(), encoding="utf-8") as fp:
         sources = [line.strip() for line in fp.readlines()]
 
     translations = []
     for path_fr in cfg.translations:
-        with open(path_fr()) as fp:
+        with open(path_fr(), encoding="utf-8") as fp:
             translations.append([line.strip() for line in fp.readlines()])
 
     if "comet-qe" in cfg.model:
         data = {"src": [sources for _ in translations], "mt": translations}
     else:
-        with open(cfg.references()) as fp:
+        with open(cfg.references(), encoding="utf-8") as fp:
             references = [line.strip() for line in fp.readlines()]
         data = {
             "src": [sources for _ in translations],
@@ -289,30 +295,37 @@ def score_command() -> None:
 
     files = [path_fr.rel_path for path_fr in cfg.translations]
     data = {file: system_data.tolist() for file, system_data in zip(files, data)}
+
     for i in range(len(data[files[0]])):  # loop over (src, ref)
         for j in range(len(files)):  # loop of system
             data[files[j]][i]["COMET"] = seg_scores[j][i]
             if cfg.mc_dropout:
                 data[files[j]][i]["variance"] = std_scores[j][i]
-                print(
-                    "{}\tSegment {}\tscore: {:.4f}\tvariance: {:.4f}".format(
-                        files[j], i, seg_scores[j][i], std_scores[j][i]
+                if not cfg.quiet:
+                    print(
+                        "{}\tSegment {}\tscore: {:.4f}\tvariance: {:.4f}".format(
+                            files[j], i, seg_scores[j][i], std_scores[j][i]
+                        )
                     )
-                )
             else:
-                print(
-                    "{}\tSegment {}\tscore: {:.4f}".format(
-                        files[j], i, seg_scores[j][i]
+                if not cfg.quiet:
+                    print(
+                        "{}\tSegment {}\tscore: {:.4f}".format(
+                            files[j], i, seg_scores[j][i]
+                        )
                     )
-                )
 
     for j in range(len(files)):
         print("{}\tscore: {:.4f}".format(files[j], sys_scores[j]))
 
     if isinstance(cfg.to_json, str):
-        with open(cfg.to_json, "w") as outfile:
+        with open(cfg.to_json, "w", encoding="utf-8") as outfile:
             json.dump(data, outfile, ensure_ascii=False, indent=4)
         print("Predictions saved in: {}.".format(cfg.to_json))
 
     if cfg.print_cache_info:
         print(model.retrieve_sentence_embedding.cache_info())
+
+
+if __name__ == "__main__":
+    score_command()
